﻿-- ********************************************************************************
-- Halo Minimalistic
-- A minimalistic halo range display.
-- By: Shenton
--
-- Options.lua
-- ********************************************************************************

--[[-------------------------------------------------------------------------------
    Globals to locals
--]]-------------------------------------------------------------------------------

local _G = _G;
local format = format;
local tonumber = tonumber;
local string = string;
local CreateFrame = CreateFrame;
local InterfaceOptions_AddCategory = InterfaceOptions_AddCategory;
local PlaySound = PlaySound;

--[[-------------------------------------------------------------------------------
    Main object
--]]-------------------------------------------------------------------------------

local A = _G["HaloMinimalisticGlobal"];
local L = A.L;

--[[-------------------------------------------------------------------------------
    Options panel
--]]-------------------------------------------------------------------------------

function A:CreateOptionsPanel()
    -- Options panel frame
    local panel = CreateFrame("Frame", "HaloMiniOptionsPanel");
    panel.layers = {};
    panel.frames = {};

    -- Adding options panel to main object
    A.optionsPanel = panel;

    -- Tab category name
    panel.name = "Halo Minimalistic";

    -- Title
    panel.layers.title = panel:CreateFontString("HaloMiniOptionsPanelTitle", "ARTWORK", "GameFontNormalLarge");
    panel.layers.title:ClearAllPoints();
    panel.layers.title:SetPoint("TOPLEFT", panel, "TOPLEFT", 16, -16);
    panel.layers.title:SetText("Halo Minimalistic");

    -- Version
    panel.layers.version = panel:CreateFontString("HaloMiniOptionsPanelVersion", "ARTWORK", "GameFontNormalLarge");
    panel.layers.version:ClearAllPoints();
    panel.layers.version:SetPoint("TOPRIGHT", panel, "TOPRIGHT", -16, -16);
    panel.layers.version:SetText(L["OPTIONS_VERSION"]:format(A.version));

    -- Lock checkbox
    panel.frames.lock = CreateFrame("CheckButton", "HaloMiniOptionsPanelLock", panel, "OptionsCheckButtonTemplate");
    panel.frames.lock:ClearAllPoints();
    panel.frames.lock:SetPoint("TOPLEFT", panel.layers.title, "BOTTOMLEFT", 0, -16);
    _G["HaloMiniOptionsPanelLockText"]:SetText(L["LOCKED"]);
    panel.frames.lock.tooltipText = L["LOCKED"];
    panel.frames.lock.tooltipRequirement = L["OPTIONS_LOCK_DESC"];
    panel.frames.lock:SetScript("OnShow", function(self)
        if ( A.db.locked ) then
            self:SetChecked(1);
        else
            self:SetChecked(nil);
        end
    end);
    panel.frames.lock:SetScript("OnClick", function(self)
        if ( self:GetChecked() ) then
            PlaySound("igMainMenuOptionCheckBoxOn");
        else
            PlaySound("igMainMenuOptionCheckBoxOff");
        end

        A.db.locked = not A.db.locked;

        if ( A.db.locked ) then
            A:Lock()
            self:SetChecked(1);
        else
            A:Unlock();
            self:SetChecked(nil);
        end
    end);

    -- Reset position button
    panel.frames.resetPos = CreateFrame("Button", "HaloMiniOptionsPanelResetPos", panel, "UIPanelButtonTemplate");
    panel.frames.resetPos:SetSize(130, 21);
    panel.frames.resetPos:ClearAllPoints();
    panel.frames.resetPos:SetPoint("LEFT", panel.frames.lock, "LEFT", 280, 0);
    _G["HaloMiniOptionsPanelResetPosText"]:SetText(L["RESET_POS"]);
    panel.frames.resetPos.tooltipText = L["OPTIONS_RESET_POS_DESC"];
    panel.frames.resetPos:SetScript("OnClick", function()
        A:ResetPos();
    end);

    -- Scale slider
    panel.frames.scale = CreateFrame("Slider", "HaloMiniOptionsPanelScale", panel, "OptionsSliderTemplate");
    panel.frames.scale:SetMinMaxValues(0.5, 3);
    panel.frames.scale:SetValueStep(0.1);
    _G["HaloMiniOptionsPanelScaleLow"]:SetText(0.5);
    _G["HaloMiniOptionsPanelScaleHigh"]:SetText(3);
    panel.frames.scale:ClearAllPoints();
    panel.frames.scale:SetPoint("TOPLEFT", panel.frames.lock, "BOTTOMLEFT", 0, -32);
    _G["HaloMiniOptionsPanelScaleText"]:SetText(L["SCALE"]);
    panel.frames.scale.tooltipText = L["SCALE"];
    panel.frames.scale.tooltipRequirement = L["OPTIONS_SCALE_DESC"];
    panel.frames.scale:SetScript("OnShow", function(self)
        self:SetValue(A.db.scale);
    end);
    panel.frames.scale:SetScript("OnValueChanged", function(self, value)
        A.db.scale = tonumber(string.format("%.1f", value));
        panel.layers.scaleValue:SetText(A.db.scale);
        A:SetScale();
    end);

    -- Scale slider value display
    panel.layers.scaleValue = panel:CreateFontString("HaloMiniOptionsPanelScaleValue", "ARTWORK", "GameFontHighlight");
    panel.layers.scaleValue:ClearAllPoints();
    panel.layers.scaleValue:SetPoint("TOP", panel.frames.scale, "BOTTOM", 0, -8);
    panel.layers.scaleValue:SetText(A.db.scale);

    -- Refresh rate slider
    panel.frames.refreshRate = CreateFrame("Slider", "HaloMiniOptionsPanelRefreshRate", panel, "OptionsSliderTemplate");
    panel.frames.refreshRate:SetMinMaxValues(0.1, 1);
    panel.frames.refreshRate:SetValueStep(0.1);
    _G["HaloMiniOptionsPanelRefreshRateLow"]:SetText(0.1);
    _G["HaloMiniOptionsPanelRefreshRateHigh"]:SetText(1);
    panel.frames.refreshRate:ClearAllPoints();
    panel.frames.refreshRate:SetPoint("TOPLEFT", panel.frames.scale, "BOTTOMLEFT", 0, -64);
    _G["HaloMiniOptionsPanelRefreshRateText"]:SetText(L["REFRESH_RATE"]);
    panel.frames.refreshRate.tooltipText = L["REFRESH_RATE"];
    panel.frames.refreshRate.tooltipRequirement = L["OPTIONS_REFRESH_RATE_DESC"];
    panel.frames.refreshRate:SetScript("OnShow", function(self)
        self:SetValue(A.db.refreshRate);
    end);
    panel.frames.refreshRate:SetScript("OnValueChanged", function(self, value)
        A.db.refreshRate = tonumber(string.format("%.1f", value));
        panel.layers.refreshRateValue:SetText(A.db.refreshRate);
    end);

    -- Refresh rate slider value display
    panel.layers.refreshRateValue = panel:CreateFontString("HaloMiniOptionsPanelRefreshRateValue", "ARTWORK", "GameFontHighlight");
    panel.layers.refreshRateValue:ClearAllPoints();
    panel.layers.refreshRateValue:SetPoint("TOP", panel.frames.refreshRate, "BOTTOM", 0, -8);
    panel.layers.refreshRateValue:SetText(A.db.refreshRate);

    -- Add panel to Blizzard interface options frame
    InterfaceOptions_AddCategory(panel);
end
